==> jc-1.4.0.tar.gz: jas/CP.c <==
// public abstract class jas.CP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class 1af4c80933b67a25 jas_ClassEnv
// @dep_class 2979cbe9083c83dc jas_jasError
// @dep_class 4bcb90cdc10424cf java_io_DataOutputStream
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String

// header file dependencies
// @dep_header jas_CP
// @dep_header jas_ClassEnv
// @dep_header jas_jasError
// @dep_header java_io_DataOutputStream
// @dep_header java_io_IOException
// @dep_header java_lang_Class
// @dep_header java_lang_String

#include "jc_defs.h"

#include "jas/CP.h"
#include "jas/ClassEnv.h"
#include "jas/jasError.h"
#include "java/io/DataOutputStream.h"
#include "java/io/IOException.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// java.lang.String uniq
static _jc_field _jc_jas_CP$field_info$uniq = {
	.name=		"uniq",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_jas_CP$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_jas_CP$object, refs[-1].jas_CP.uniq),
};

// Fields
static _jc_field *const _jc_jas_CP$fields[] = {
	&_jc_jas_CP$field_info$uniq
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_jas_CP$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_jas_CP$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_jas_CP$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_jas_CP$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_jas_CP$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_jas_CP$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_jas_CP$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(jas_CP, _init$52f4ad9f2989aeee);

void
_jc_jas_CP$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_jas_CP$object *this)
{
	struct _jc_jas_CP$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(27);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// java.lang.String getUniq()
//

static _jc_linenum _jc_jas_CP$linenum_table$getUniq$0f11f9cb5c3ec6cc[];

static const unsigned char _jc_jas_CP$param_ptypes$getUniq$0f11f9cb5c3ec6cc[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_jas_CP$method_info$getUniq$0f11f9cb5c3ec6cc = {
	.name=			"getUniq",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_jas_CP$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_jas_CP$param_ptypes$getUniq$0f11f9cb5c3ec6cc,
	.signature_hash=	_JC_JLONG(0xf11f9cb5c3ec6cc),
	.access_flags=		0,
	.function=		&_jc_jas_CP$method$getUniq$0f11f9cb5c3ec6cc,
	.vtable_index=		_JC_OFFSETOF(struct _jc_jas_CP$vtable, jas_CP.getUniq$0f11f9cb5c3ec6cc) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_jas_CP$linenum_table$getUniq$0f11f9cb5c3ec6cc
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(jas_CP, getUniq$0f11f9cb5c3ec6cc);

_jc_java_lang_String$object *
_jc_jas_CP$method$getUniq$0f11f9cb5c3ec6cc(_jc_env *const env, _jc_jas_CP$object *this)
{
	struct _jc_jas_CP$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(31);				// 0
	r1 = _JC_REF_FIELD(env, r0, jas_CP, uniq);
	return r1;
}

//
// abstract void resolve(jas.ClassEnv)
//

static const unsigned char _jc_jas_CP$param_ptypes$resolve$f7bbca8128967cc2[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_jas_CP$param_types$resolve$f7bbca8128967cc2[] = {
	&_jc_jas_ClassEnv$type
};

_jc_method _jc_jas_CP$method_info$resolve$f7bbca8128967cc2 = {
	.name=			"resolve",
	.signature=		"(Ljas/ClassEnv;)V",
	.class=			&_jc_jas_CP$type,
	.param_types=		&_jc_jas_CP$param_types$resolve$f7bbca8128967cc2,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_jas_CP$param_ptypes$resolve$f7bbca8128967cc2,
	.signature_hash=	_JC_JLONG(0xf7bbca8128967cc2),
	.access_flags=		_JC_ACC_ABSTRACT,
	.function=		&_jc_jas_CP$method$resolve$f7bbca8128967cc2,
	.vtable_index=		_JC_OFFSETOF(struct _jc_jas_CP$vtable, jas_CP.resolve$f7bbca8128967cc2) / sizeof(void *),
	.num_parameters=	1,
};

void
_jc_jas_CP$method$resolve$f7bbca8128967cc2(_jc_env *const env, _jc_jas_CP$object *this, _jc_jas_ClassEnv$object *param0)
{
	_JC_ABSTRACT_METHOD(env, &_jc_jas_CP$method_info$resolve$f7bbca8128967cc2);
}

//
// abstract void write(jas.ClassEnv, java.io.DataOutputStream) throws java.io.IOException, jas.jasError
//

static const unsigned char _jc_jas_CP$param_ptypes$write$c5719140f8114b75[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_jas_CP$exceptions$write$c5719140f8114b75[] = {
	&_jc_java_io_IOException$type,
	&_jc_jas_jasError$type
};

static _jc_type *const _jc_jas_CP$param_types$write$c5719140f8114b75[] = {
	&_jc_jas_ClassEnv$type,
	&_jc_java_io_DataOutputStream$type
};

_jc_method _jc_jas_CP$method_info$write$c5719140f8114b75 = {
	.name=			"write",
	.signature=		"(Ljas/ClassEnv;Ljava/io/DataOutputStream;)V",
	.class=			&_jc_jas_CP$type,
	.param_types=		&_jc_jas_CP$param_types$write$c5719140f8114b75,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_jas_CP$param_ptypes$write$c5719140f8114b75,
	.signature_hash=	_JC_JLONG(0xc5719140f8114b75),
	.access_flags=		_JC_ACC_ABSTRACT,
	.function=		&_jc_jas_CP$method$write$c5719140f8114b75,
	.vtable_index=		_JC_OFFSETOF(struct _jc_jas_CP$vtable, jas_CP.write$c5719140f8114b75) / sizeof(void *),
	.num_parameters=	2,
	.num_exceptions=	2,
	.exceptions=		&_jc_jas_CP$exceptions$write$c5719140f8114b75,
};

void
_jc_jas_CP$method$write$c5719140f8114b75(_jc_env *const env, _jc_jas_CP$object *this, _jc_jas_ClassEnv$object *param0, _jc_java_io_DataOutputStream$object *param1)
{
	_JC_ABSTRACT_METHOD(env, &_jc_jas_CP$method_info$write$c5719140f8114b75);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_jas_CP$methods[] = {
	&_jc_jas_CP$method_info$_init$52f4ad9f2989aeee,
	&_jc_jas_CP$method_info$getUniq$0f11f9cb5c3ec6cc,
	&_jc_jas_CP$method_info$resolve$f7bbca8128967cc2,
	&_jc_jas_CP$method_info$write$c5719140f8114b75
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_jas_CP$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_jas_CP$instanceof_hash_bucket_115[] = {
	&_jc_jas_CP$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_jas_CP$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[113]=	_jc_jas_CP$instanceof_hash_bucket_113,
	[115]=	_jc_jas_CP$instanceof_hash_bucket_115
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_jas_CP$class_depends[] = {
	{ "jas/ClassEnv",	_JC_JLONG(0x1af4c80933b67a25) },
	{ "jas/jasError",	_JC_JLONG(0x2979cbe9083c83dc) },
	{ "java/io/DataOutputStream",	_JC_JLONG(0x4bcb90cdc10424cf) },
	{ "java/io/IOException",	_JC_JLONG(0x4e0a56550c69d57c) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_jas_CP$vtype _jc_jas_CP$type = {
    .type= {
	.name=			"jas/CP",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0xc0e5264359137f3),
		.source_file=		"CP.java",
		.instance_size=		sizeof(_jc_jas_CP$refs) + sizeof(_jc_jas_CP$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_jas_CP$fields) / sizeof(*_jc_jas_CP$fields),
		.fields=		_jc_jas_CP$fields,
		.num_methods=		sizeof(_jc_jas_CP$methods) / sizeof(*_jc_jas_CP$methods),
		.methods=		_jc_jas_CP$methods,
		.instanceof_hash_table=	_jc_jas_CP$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_jas_CP$class_depends) / sizeof(*_jc_jas_CP$class_depends),
		.class_depends=		_jc_jas_CP$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.jas_CP= {
	    .getUniq$0f11f9cb5c3ec6cc=
		&_jc_jas_CP$method$getUniq$0f11f9cb5c3ec6cc,
	    .resolve$f7bbca8128967cc2=
		&_jc_jas_CP$method$resolve$f7bbca8128967cc2,
	    .write$c5719140f8114b75=
		&_jc_jas_CP$method$write$c5719140f8114b75,
	},
    }
};

==> jc-1.4.5.tar.gz: jas/CP.c <==
// public abstract class jas.CP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class 1af4c80933b67a25 jas_ClassEnv
// @dep_class 2979cbe9083c83dc jas_jasError
// @dep_class d755b96203d8fbaf java_io_DataOutputStream
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String

// header file dependencies
// @dep_header jas_CP
// @dep_header jas_ClassEnv
// @dep_header jas_jasError
// @dep_header java_io_DataOutputStream
// @dep_header java_io_IOException
// @dep_header java_lang_Class
// @dep_header java_lang_String

#include "jc_defs.h"

#include "jas/CP.h"
#include "jas/ClassEnv.h"
#include "jas/jasError.h"
#include "java/io/DataOutputStream.h"
#include "java/io/IOException.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// java.lang.String uniq
static _jc_field _jc_jas_CP$field_info$uniq = {
	.name=		"uniq",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_jas_CP$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_jas_CP$object, refs[-1].jas_CP.uniq),
};

// Fields
static _jc_field *const _jc_jas_CP$fields[] = {
	&_jc_jas_CP$field_info$uniq
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_jas_CP$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_jas_CP$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_jas_CP$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_jas_CP$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_jas_CP$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_jas_CP$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_jas_CP$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(jas_CP, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_jas_CP$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_jas_CP$object *this)
{
	struct _jc_jas_CP$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(27);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// java.lang.String getUniq()
//

static _jc_linenum _jc_jas_CP$linenum_table$getUniq$0f11f9cb5c3ec6cc[];

static const unsigned char _jc_jas_CP$param_ptypes$getUniq$0f11f9cb5c3ec6cc[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_jas_CP$method_info$getUniq$0f11f9cb5c3ec6cc = {
	.name=			"getUniq",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_jas_CP$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_jas_CP$param_ptypes$getUniq$0f11f9cb5c3ec6cc,
	.signature_hash=	_JC_JLONG(0xf11f9cb5c3ec6cc),
	.access_flags=		0,
	.function=		&_jc_jas_CP$method$getUniq$0f11f9cb5c3ec6cc,
	.vtable_index=		_JC_OFFSETOF(struct _jc_jas_CP$vtable, jas_CP.getUniq$0f11f9cb5c3ec6cc) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_jas_CP$linenum_table$getUniq$0f11f9cb5c3ec6cc
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(jas_CP, getUniq$0f11f9cb5c3ec6cc);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_jas_CP$method$getUniq$0f11f9cb5c3ec6cc(_jc_env *const env, _jc_jas_CP$object *this)
{
	struct _jc_jas_CP$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(31);				// 0
	r1 = _JC_REF_FIELD(env, r0, jas_CP, uniq);
	return r1;
}

//
// abstract void resolve(jas.ClassEnv)
//

static const unsigned char _jc_jas_CP$param_ptypes$resolve$f7bbca8128967cc2[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_jas_CP$param_types$resolve$f7bbca8128967cc2[] = {
	&_jc_jas_ClassEnv$type
};

_jc_method _jc_jas_CP$method_info$resolve$f7bbca8128967cc2 = {
	.name=			"resolve",
	.signature=		"(Ljas/ClassEnv;)V",
	.class=			&_jc_jas_CP$type,
	.param_types=		&_jc_jas_CP$param_types$resolve$f7bbca8128967cc2,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_jas_CP$param_ptypes$resolve$f7bbca8128967cc2,
	.signature_hash=	_JC_JLONG(0xf7bbca8128967cc2),
	.access_flags=		_JC_ACC_ABSTRACT,
	.function=		&_jc_jas_CP$method$resolve$f7bbca8128967cc2,
	.vtable_index=		_JC_OFFSETOF(struct _jc_jas_CP$vtable, jas_CP.resolve$f7bbca8128967cc2) / sizeof(void *),
	.num_parameters=	1,
};

void _JC_JCNI_ATTR
_jc_jas_CP$method$resolve$f7bbca8128967cc2(_jc_env *const env, _jc_jas_CP$object *this, _jc_jas_ClassEnv$object *param0)
{
	_JC_ABSTRACT_METHOD(env, &_jc_jas_CP$method_info$resolve$f7bbca8128967cc2);
}

//
// abstract void write(jas.ClassEnv, java.io.DataOutputStream) throws java.io.IOException, jas.jasError
//

static const unsigned char _jc_jas_CP$param_ptypes$write$c5719140f8114b75[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_jas_CP$exceptions$write$c5719140f8114b75[] = {
	&_jc_java_io_IOException$type,
	&_jc_jas_jasError$type
};

static _jc_type *const _jc_jas_CP$param_types$write$c5719140f8114b75[] = {
	&_jc_jas_ClassEnv$type,
	&_jc_java_io_DataOutputStream$type
};

_jc_method _jc_jas_CP$method_info$write$c5719140f8114b75 = {
	.name=			"write",
	.signature=		"(Ljas/ClassEnv;Ljava/io/DataOutputStream;)V",
	.class=			&_jc_jas_CP$type,
	.param_types=		&_jc_jas_CP$param_types$write$c5719140f8114b75,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_jas_CP$param_ptypes$write$c5719140f8114b75,
	.signature_hash=	_JC_JLONG(0xc5719140f8114b75),
	.access_flags=		_JC_ACC_ABSTRACT,
	.function=		&_jc_jas_CP$method$write$c5719140f8114b75,
	.vtable_index=		_JC_OFFSETOF(struct _jc_jas_CP$vtable, jas_CP.write$c5719140f8114b75) / sizeof(void *),
	.num_parameters=	2,
	.num_exceptions=	2,
	.exceptions=		&_jc_jas_CP$exceptions$write$c5719140f8114b75,
};

void _JC_JCNI_ATTR
_jc_jas_CP$method$write$c5719140f8114b75(_jc_env *const env, _jc_jas_CP$object *this, _jc_jas_ClassEnv$object *param0, _jc_java_io_DataOutputStream$object *param1)
{
	_JC_ABSTRACT_METHOD(env, &_jc_jas_CP$method_info$write$c5719140f8114b75);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_jas_CP$methods[] = {
	&_jc_jas_CP$method_info$_init$52f4ad9f2989aeee,
	&_jc_jas_CP$method_info$getUniq$0f11f9cb5c3ec6cc,
	&_jc_jas_CP$method_info$resolve$f7bbca8128967cc2,
	&_jc_jas_CP$method_info$write$c5719140f8114b75
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_jas_CP$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_jas_CP$instanceof_hash_bucket_115[] = {
	&_jc_jas_CP$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_jas_CP$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[101]=	_jc_jas_CP$instanceof_hash_bucket_101,
	[115]=	_jc_jas_CP$instanceof_hash_bucket_115
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_jas_CP$class_depends[] = {
	{ "jas/ClassEnv",	_JC_JLONG(0x1af4c80933b67a25) },
	{ "jas/jasError",	_JC_JLONG(0x2979cbe9083c83dc) },
	{ "java/io/DataOutputStream",	_JC_JLONG(0xd755b96203d8fbaf) },
	{ "java/io/IOException",	_JC_JLONG(0x4e0a56550c69d57c) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_jas_CP$vtype _jc_jas_CP$type = {
    .type= {
	.name=			"jas/CP",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0xc0e5264359137f3),
		.source_file=		"CP.java",
		.instance_size=		sizeof(_jc_jas_CP$refs) + sizeof(_jc_jas_CP$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_jas_CP$fields) / sizeof(*_jc_jas_CP$fields),
		.fields=		_jc_jas_CP$fields,
		.num_methods=		sizeof(_jc_jas_CP$methods) / sizeof(*_jc_jas_CP$methods),
		.methods=		_jc_jas_CP$methods,
		.instanceof_hash_table=	_jc_jas_CP$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_jas_CP$class_depends) / sizeof(*_jc_jas_CP$class_depends),
		.class_depends=		_jc_jas_CP$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.jas_CP= {
	    .getUniq$0f11f9cb5c3ec6cc=
		&_jc_jas_CP$method$getUniq$0f11f9cb5c3ec6cc,
	    .resolve$f7bbca8128967cc2=
		&_jc_jas_CP$method$resolve$f7bbca8128967cc2,
	    .write$c5719140f8114b75=
		&_jc_jas_CP$method$write$c5719140f8114b75,
	},
    }
};
